;FOR MORE INFORMATION:
; go to http://www.delorie.com/djgpp/doc/rbinter
; for Ralph Brown's interrupt list

%macro m_DosTerminateProcess 1
	;this calls DOS to terminate the current program

	;on the calc, this returns to the menu screen.

	;termination code is the only parameter

	;does not return control to program
	mov al,%1
	mov ah,0x4C
	int 0x21
%endmacro

%macro m_DosDisplayCharacter 1
	;displays the character in the parameter to
	;the screen

	;despite the official docs which state
	;nothing is returned, AL will contain the last
	;character displayed (will be 0x20 if a tab 
	;was displayed)

	;Registers destroyed:  AX, DL
	mov dl,%1
	mov ah,0x02
	int 0x21
%endmacro

%macro m_DosReadKeyboard 0
	;waits for a keypress and stores the result in AL
	;the character is not echoed to the screen

	;Registers destroyed: AH
	mov ah,0x08
	int 0x21
%endmacro

%macro m_DosDisplayString 1
	;this calls DOS to display the '$' terminated string at
	;[DS:parameter]

	;Note that there is a much more effecient way to accomplish
	;this through the BIOS... use this only if you need i/o
	;redirection support [See m_FastDisplayString in misc.h]

	;Registers destroyed: AX, DX (AL destroyed in a similar
	;fashion as in m_DosDisplayCharacter)
	mov dx,%1
	mov ah,0x09
	int 0x21
%endmacro

%macro m_DosGetTime 0
	;this call is used to make DOS load various registers with
	;the current system time.  Note that this time goes about
	;2.7 times faster than normal on the calc due to the way
	;their timer is set up.  [Read hardware.txt for more info]
	
	;Return values:
	;CH=hour
	;CL=minute
	;DH=second
	;DL=1/100 seconds

	;Registers destroyed: AH

	mov ah,0x2c
	int 0x21
%endmacro

%macro m_DosCheckKeyboardStatus 0
	;this checks for the presence of keys in the type ahead
	;buffer.

	;Return value:
	;AL=00 if no character is available
	;AL=FF if character(s) are available

	;Registers destroyed: AH

	mov ah,0x0b
	int 0x21
%endmacro

%macro m_DosOpenFile 1
	;this is a more advanced call and I won't go into detail 
	;on how it is used here.  See MS-DOS programming
	;documentation for more details.

	mov dx,%1
	mov ax,0x3d02
	int 0x21
%endmacro

%macro m_DosCloseFileHandleBX 0
	;this is a more advanced call and I won't go into detail 
	;on how it is used here.  See MS-DOS programming
	;documentation for more details.

	mov ah,0x3e
	int 0x21
%endmacro

%macro m_DosCreateFile 2
	;this is a more advanced call and I won't go into detail 
	;on how it is used here.  See MS-DOS programming
	;documentation for more details.

	mov dx,%1
	mov cx,%2
	mov ah,0x3c
	int 0x21
%endmacro

%macro m_DosWriteFileDevice 1
	;this is a more advanced call and I won't go into detail 
	;on how it is used here.  See MS-DOS programming
	;documentation for more details.

	mov dx,%1
	mov ah,0x40
	int 0x21
%endmacro

%macro m_DosLoadExecuteProgram 3
	;this is a more advanced call and I won't go into detail 
	;on how it is used here.  See MS-DOS programming
	;documentation for more details.

	mov dx,%1
	mov bx,%2
	mov al,%3
	mov ah,0x4b
	int 0x21
%endmacro